==> vixeny-0.0.945.tgz: package/components/http/src/framework/optimizer/response.ts <==
import { FunRouterOptions } from "../../../types.ts";
import { CommonRequestMorphism, RequestMorphism } from "./types.ts";
import { stringToFunction , parse } from "../../cors/mainCORS.ts";
import checkAsync from "./recursiveCheckAsync.ts";
import aComposer from "./aComposer.ts";
import mime from "../../util/mime.ts";
import isUsing from "./tools/isUsing.ts";

export default (o?: FunRouterOptions) =>
(f: CommonRequestMorphism | RequestMorphism) =>
  ((elementsUsed) =>
    (
      (table) =>
        ((composition) =>
          (table.headers && table.json)
            ? composition(table.json)(table.headers)(f.f)(
              aComposer(o)(f)(elementsUsed),
            )
            : table.headers
            ? composition(table.headers)(f.f)(
              aComposer(o)(f)(elementsUsed),
            )
            : table.json
            ? composition(table.json)(f.f)(
              aComposer(o)(f)(elementsUsed),
            )
            : composition(f.f)(
              aComposer(o)(f)(elementsUsed),
            ))(
            "type" in f
              ? new Function(`
      return f=>c=>${table.async || table.asyncResolve ? "async " : ""}r=>${
                table.async || table.asyncResolve ? "await f" : "f"
              }(${table.asyncResolve ? "await c" : "c"}(${
                "mutable" in f ? "[r,{res: new Response()}]" : "r"
              }))`)()
              : new Function(
                `return ${table.headers ? "h=>" : ""}${
                  table.async ? "f=>" : "f=>"
                }${table.asyncResolve ? "c=>" : "c=>"}${
                  table.async || table.asyncResolve ? "async " : ""
                }r=> new Response(${
                  table.async || table.asyncResolve ? "await f" : "f"
                }(${table.asyncResolve ? "await c" : "c"}(${
                  "mutable" in f ? "[r,{res: new Response()}]" : "r"
                }))${table.headers ? ",h" : ""})`,
              )(),
          )
    )(
      {
        async: f.f.constructor.name === "AsyncFunction" ||
          (
            o && o.cyclePlugin && Object.keys(o.cyclePlugin || {})
              .some((x) =>
                elementsUsed.includes(x)
                  //@ts-ignore
                  ? "isAsync" in o.cyclePlugin[x] && o.cyclePlugin[x] === true
                  : false
              )
          ),
        asyncResolve: checkAsync(f) ||
          (
            o && o.cyclePlugin && Object.keys(o.cyclePlugin || {})
              .some((x) =>
                elementsUsed.includes(x)
                  //@ts-ignore
                  ? "isAsync" in o.cyclePlugin[x] && o.cyclePlugin[x] === true
                  : false
              )
          ),
        headers: "headings" in f
          ? typeof f.headings?.headers == "string"
            ? {
              ...f.headings,
              headers: {
                "Content-Type":
                  mime.find((x) => x[0] === f.headings?.headers)![1],
                  ...(o && o.cors ? stringToFunction(parse()(o.cors))(): {}) 
              },
            }
            : { ...f.headings , ...(o && o.cors ? stringToFunction(parse()(o.cors))(): {}) }
          : null,
        json: "json" in f
          ? null //jsonComposer({ type: "safe" })(f.json.scheme)
          : null,
      },
    ))(
      isUsing(o)(f),
    );

==> vixeny-0.0.955.tgz: package/components/http/src/framework/optimizer/response.ts <==
import { FunRouterOptions } from "../../../types.ts";
import { CommonRequestMorphism, RequestMorphism } from "./types.ts";
import { parse, stringToFunction } from "../../cors/mainCORS.ts";
import checkAsync from "./recursiveCheckAsync.ts";
import aComposer from "./aComposer.ts";
import mime from "../../util/mime.ts";
import isUsing from "./tools/isUsing.ts";

export default (o?: FunRouterOptions) =>
(f: CommonRequestMorphism | RequestMorphism) =>
  ((elementsUsed) =>
    (
      (table) =>
        ((composition) =>
          (table.headers && table.json)
            ? composition(table.json)(table.headers)(f.f)(
              aComposer(o)(f)(elementsUsed),
            )
            : table.headers
            ? composition(table.headers)(f.f)(
              aComposer(o)(f)(elementsUsed),
            )
            : table.json
            ? composition(table.json)(f.f)(
              aComposer(o)(f)(elementsUsed),
            )
            : composition(f.f)(
              aComposer(o)(f)(elementsUsed),
            ))(
            "type" in f
              ? new Function(`
      return f=>c=>${table.async || table.asyncResolve ? "async " : ""}r=>${
                table.async || table.asyncResolve ? "await f" : "f"
              }(${table.asyncResolve ? "await c" : "c"}(${
                "mutable" in f ? "[r,{res: new Response()}]" : "r"
              }))`)()
              : new Function(
                `return ${table.headers ? "h=>" : ""}${
                  table.async ? "f=>" : "f=>"
                }${table.asyncResolve ? "c=>" : "c=>"}${
                  table.async || table.asyncResolve ? "async " : ""
                }r=> new Response(${
                  table.async || table.asyncResolve ? "await f" : "f"
                }(${table.asyncResolve ? "await c" : "c"}(${
                  "mutable" in f ? "[r,{res: new Response()}]" : "r"
                }))${table.headers ? ",h" : ""})`,
              )(),
          )
    )(
      {
        async: f.f.constructor.name === "AsyncFunction" ||
          (
            o && o.cyclePlugin && Object.keys(o.cyclePlugin || {})
              .some((x) =>
                elementsUsed.includes(x)
                  //@ts-ignore
                  ? "isAsync" in o.cyclePlugin[x] && o.cyclePlugin[x] === true
                  : false
              )
          ),
        asyncResolve: checkAsync(f) ||
          (
            o && o.cyclePlugin && Object.keys(o.cyclePlugin || {})
              .some((x) =>
                elementsUsed.includes(x)
                  //@ts-ignore
                  ? "isAsync" in o.cyclePlugin[x] && o.cyclePlugin[x] === true
                  : false
              )
          ),
        headers: "headings" in f
          ? typeof f.headings?.headers == "string"
            ? {
              ...f.headings,
              headers: {
                "Content-Type":
                  mime.find((x) => x[0] === f.headings?.headers)![1],
                ...(o && o.cors ? stringToFunction(parse()(o.cors))() : {}),
              },
            }
            : {
              ...f.headings,
              ...(o && o.cors ? stringToFunction(parse()(o.cors))() : {}),
            }
          : null,
        json: "json" in f
          ? null //jsonComposer({ type: "safe" })(f.json.scheme)
          : null,
      },
    ))(
      isUsing(o)(f),
    );
